import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsx as _jsx } from "react/jsx-runtime";
import { lazy, useState, useEffect, useRef, Suspense } from 'react';
import cx from 'classnames';
import markerFactory from './markerFactory';
var BASE_CLASS = "sui-AtomSlider";
var CLASS_DISABLED = BASE_CLASS + "--disabled";
var CLASS_INVERSE = BASE_CLASS + "--inverse";
var Range = /*#__PURE__*/lazy(function () {
  return import('rc-slider/lib/Range');
});
var Slider = /*#__PURE__*/lazy(function () {
  return import('rc-slider/lib/Slider');
});
var Tooltip = /*#__PURE__*/lazy(function () {
  return import('rc-tooltip');
});
var Label = /*#__PURE__*/lazy(function () {
  return import('./Label');
});

var createHandler = function createHandler(refAtomSlider, handleComponent, hideTooltip) {
  return function (props) {
    var value = props.value,
        index = props.index,
        dragging = props.dragging,
        restProps = _objectWithoutPropertiesLoose(props, ["value", "index", "dragging"]); // eslint-disable-line


    var Handle = handleComponent.component;

    if (hideTooltip) {
      return /*#__PURE__*/_jsx(Handle, _extends({
        value: value
      }, restProps, {
        dragging: dragging.toString()
      }));
    }

    return /*#__PURE__*/_jsx(Tooltip, {
      getTooltipContainer: function getTooltipContainer() {
        return refAtomSlider.current;
      },
      overlay: value,
      placement: "top",
      prefixCls: "rc-slider-tooltip",
      visible: true,
      children: /*#__PURE__*/_jsx(Handle, _extends({
        value: value
      }, restProps, {
        dragging: dragging.toString()
      }))
    }, index);
  };
};

var AtomSlider = function AtomSlider(_ref) {
  var _cx, _cx2;

  var onChange = _ref.onChange,
      onAfterChange = _ref.onAfterChange,
      value = _ref.value,
      min = _ref.min,
      max = _ref.max,
      step = _ref.step,
      range = _ref.range,
      disabled = _ref.disabled,
      valueLabel = _ref.valueLabel,
      marks = _ref.marks,
      valueLabelFormatter = _ref.valueLabelFormatter,
      hideTooltip = _ref.hideTooltip,
      defaultValue = _ref.defaultValue,
      invertColors = _ref.invertColors;

  var _useState = useState(false),
      ready = _useState[0],
      setReady = _useState[1];

  var _useState2 = useState({
    component: null
  }),
      handleComponent = _useState2[0],
      setHandle = _useState2[1];

  var _useState3 = useState(value || min),
      labelValue = _useState3[0],
      setLabelValue = _useState3[1];

  var refAtomSlider = useRef();
  useEffect(function () {
    // import Handle here and set it in the state as tooltip need this to be loaded
    // before trying to be shown, otherwise, the reference is wrong
    // and the tooltip is not positioned correctly
    import('rc-slider/lib/Handle').then(function (_ref2) {
      var Handle = _ref2["default"];
      setHandle({
        component: Handle
      });
      setReady(true);
    });
    setLabelValue(value || min);
  }, [min, value]);

  var handleChange = function handleChange(value) {
    var e = {};
    setLabelValue(value);
    onChange(e, {
      value: value
    });
  };

  var handleAfterChange = function handleAfterChange(value) {
    var e = {};
    onAfterChange(e, {
      value: value
    });
  };

  var customProps = {
    defaultValue: defaultValue || (range ? [min, max] : value),
    handle: createHandler(refAtomSlider, handleComponent, hideTooltip),
    onChange: handleChange,
    onAfterChange: handleAfterChange,
    disabled: disabled,
    marks: markerFactory({
      step: step,
      min: min,
      max: max,
      marks: marks
    }),
    max: max,
    min: min,
    step: step,
    value: value
  }; // Determine the type of the slider according to the range prop

  var Type = range ? Range : Slider;
  return /*#__PURE__*/_jsx("div", {
    ref: refAtomSlider,
    className: cx(BASE_CLASS, (_cx = {}, _cx[CLASS_DISABLED] = disabled, _cx), (_cx2 = {}, _cx2[CLASS_INVERSE] = invertColors, _cx2)),
    children: ready && /*#__PURE__*/_jsx(Suspense, {
      fallback: null,
      children: valueLabel ? /*#__PURE__*/_jsxs(_Fragment, {
        children: [/*#__PURE__*/_jsx(Label, {
          value: labelValue,
          formatter: valueLabelFormatter,
          percentage: (labelValue - min) / (max - min) * 100
        }), /*#__PURE__*/_jsx(Type, _extends({}, customProps))]
      }) : /*#__PURE__*/_jsx(Type, _extends({}, customProps))
    })
  });
};

AtomSlider.displayName = 'AtomSlider';
AtomSlider.defaultProps = {
  min: 0,
  max: 100,
  step: 1,
  onChange: function onChange() {},
  onAfterChange: function onAfterChange() {},
  hideTooltip: false
};
export default AtomSlider;